==> ejc-law-api-3.0.0-20231106.071612-88-sources.jar: com/ejianc/business/law/desktop/vo/CaseBaseVO.java <==
package com.ejianc.business.law.desktop.vo;


import java.math.BigDecimal;
import java.util.HashMap;

/**
 * 门户案件数量、金额统计
 * 
 *
 */
public class CaseBaseVO{

    /**
     * 应诉
     */
    private Integer progressCases; //在办案件
    private BigDecimal progressCasesMny;

    private Integer importantCases;//在办重大案件
    private BigDecimal importantCasesMny;

    private Integer thisYearAddCases;//本年新增案件
    private BigDecimal thisYearAddCasesMny;

    private Integer thisYearEndCases;//本年结案案件
    private BigDecimal thisYearEndMny;

    private HashMap<String,String> caseTypeResult;//案件类型占比

    /**
     * 起诉
     */
    private Integer proProgressCases; //在办案件
    private BigDecimal proProgressCasesMny;

    private Integer proImportantCases;//在办重大案件
    private BigDecimal proImportantCasesMny;

    private Integer proThisYearAddCases;//本年新增案件
    private BigDecimal proThisYearAddCasesMny;

    private Integer proThisYearEndCases;//本年结案案件
    private BigDecimal proThisYearEndMny;

    private HashMap<String,String> proCaseTypeResult;//案件类型占比


    public Integer getProgressCases() {
        return progressCases;
    }

    public void setProgressCases(Integer progressCases) {
        this.progressCases = progressCases;
    }

    public BigDecimal getProgressCasesMny() {
        return progressCasesMny;
    }

    public void setProgressCasesMny(BigDecimal progressCasesMny) {
        this.progressCasesMny = progressCasesMny;
    }

    public Integer getImportantCases() {
        return importantCases;
    }

    public void setImportantCases(Integer importantCases) {
        this.importantCases = importantCases;
    }

    public BigDecimal getImportantCasesMny() {
        return importantCasesMny;
    }

    public void setImportantCasesMny(BigDecimal importantCasesMny) {
        this.importantCasesMny = importantCasesMny;
    }

    public Integer getThisYearAddCases() {
        return thisYearAddCases;
    }

    public void setThisYearAddCases(Integer thisYearAddCases) {
        this.thisYearAddCases = thisYearAddCases;
    }

    public BigDecimal getThisYearAddCasesMny() {
        return thisYearAddCasesMny;
    }

    public void setThisYearAddCasesMny(BigDecimal thisYearAddCasesMny) {
        this.thisYearAddCasesMny = thisYearAddCasesMny;
    }

    public Integer getThisYearEndCases() {
        return thisYearEndCases;
    }

    public void setThisYearEndCases(Integer thisYearEndCases) {
        this.thisYearEndCases = thisYearEndCases;
    }

    public BigDecimal getThisYearEndMny() {
        return thisYearEndMny;
    }

    public void setThisYearEndMny(BigDecimal thisYearEndMny) {
        this.thisYearEndMny = thisYearEndMny;
    }

    public Integer getProProgressCases() {
        return proProgressCases;
    }

    public void setProProgressCases(Integer proProgressCases) {
        this.proProgressCases = proProgressCases;
    }

    public BigDecimal getProProgressCasesMny() {
        return proProgressCasesMny;
    }

    public void setProProgressCasesMny(BigDecimal proProgressCasesMny) {
        this.proProgressCasesMny = proProgressCasesMny;
    }

    public Integer getProImportantCases() {
        return proImportantCases;
    }

    public void setProImportantCases(Integer proImportantCases) {
        this.proImportantCases = proImportantCases;
    }

    public BigDecimal getProImportantCasesMny() {
        return proImportantCasesMny;
    }

    public void setProImportantCasesMny(BigDecimal proImportantCasesMny) {
        this.proImportantCasesMny = proImportantCasesMny;
    }

    public Integer getProThisYearAddCases() {
        return proThisYearAddCases;
    }

    public void setProThisYearAddCases(Integer proThisYearAddCases) {
        this.proThisYearAddCases = proThisYearAddCases;
    }

    public BigDecimal getProThisYearAddCasesMny() {
        return proThisYearAddCasesMny;
    }

    public void setProThisYearAddCasesMny(BigDecimal proThisYearAddCasesMny) {
        this.proThisYearAddCasesMny = proThisYearAddCasesMny;
    }

    public Integer getProThisYearEndCases() {
        return proThisYearEndCases;
    }

    public void setProThisYearEndCases(Integer proThisYearEndCases) {
        this.proThisYearEndCases = proThisYearEndCases;
    }

    public BigDecimal getProThisYearEndMny() {
        return proThisYearEndMny;
    }

    public void setProThisYearEndMny(BigDecimal proThisYearEndMny) {
        this.proThisYearEndMny = proThisYearEndMny;
    }
}

==> ejc-law-api-3.0.0-20240726.064907-93-sources.jar: com/ejianc/business/law/desktop/vo/CaseBaseVO.java <==
package com.ejianc.business.law.desktop.vo;


import java.math.BigDecimal;
import java.util.HashMap;

/**
 * 门户案件数量、金额统计
 * 
 *
 */
public class CaseBaseVO{

    /**
     * 应诉
     */
    private Integer progressCases; //在办案件
    private BigDecimal progressCasesMny;

    private Integer importantCases;//在办重大案件
    private BigDecimal importantCasesMny;

    private Integer thisYearAddCases;//本年新增案件

    private Integer sevenDaysAddCases;//近七天新增案件
    private BigDecimal thisYearAddCasesMny;

    private Integer thisYearEndCases;//本年结案案件
    private BigDecimal thisYearEndMny;

    private HashMap<String,String> caseTypeResult;//案件类型占比

    /**
     * 起诉
     */
    private Integer proProgressCases; //在办案件
    private BigDecimal proProgressCasesMny;

    private Integer proImportantCases;//在办重大案件
    private BigDecimal proImportantCasesMny;

    private Integer proSevenDaysAddCases;//近七天新增案件

    private Integer proThisYearAddCases;//本年新增案件
    private BigDecimal proThisYearAddCasesMny;

    private Integer proThisYearEndCases;//本年结案案件
    private BigDecimal proThisYearEndMny;

    private HashMap<String,String> proCaseTypeResult;//案件类型占比


    public Integer getProgressCases() {
        return progressCases;
    }

    public void setProgressCases(Integer progressCases) {
        this.progressCases = progressCases;
    }

    public BigDecimal getProgressCasesMny() {
        return progressCasesMny;
    }

    public void setProgressCasesMny(BigDecimal progressCasesMny) {
        this.progressCasesMny = progressCasesMny;
    }

    public Integer getImportantCases() {
        return importantCases;
    }

    public void setImportantCases(Integer importantCases) {
        this.importantCases = importantCases;
    }

    public BigDecimal getImportantCasesMny() {
        return importantCasesMny;
    }

    public void setImportantCasesMny(BigDecimal importantCasesMny) {
        this.importantCasesMny = importantCasesMny;
    }

    public Integer getThisYearAddCases() {
        return thisYearAddCases;
    }

    public void setThisYearAddCases(Integer thisYearAddCases) {
        this.thisYearAddCases = thisYearAddCases;
    }

    public BigDecimal getThisYearAddCasesMny() {
        return thisYearAddCasesMny;
    }

    public void setThisYearAddCasesMny(BigDecimal thisYearAddCasesMny) {
        this.thisYearAddCasesMny = thisYearAddCasesMny;
    }

    public Integer getThisYearEndCases() {
        return thisYearEndCases;
    }

    public void setThisYearEndCases(Integer thisYearEndCases) {
        this.thisYearEndCases = thisYearEndCases;
    }

    public BigDecimal getThisYearEndMny() {
        return thisYearEndMny;
    }

    public void setThisYearEndMny(BigDecimal thisYearEndMny) {
        this.thisYearEndMny = thisYearEndMny;
    }

    public Integer getProProgressCases() {
        return proProgressCases;
    }

    public void setProProgressCases(Integer proProgressCases) {
        this.proProgressCases = proProgressCases;
    }

    public BigDecimal getProProgressCasesMny() {
        return proProgressCasesMny;
    }

    public void setProProgressCasesMny(BigDecimal proProgressCasesMny) {
        this.proProgressCasesMny = proProgressCasesMny;
    }

    public Integer getProImportantCases() {
        return proImportantCases;
    }

    public void setProImportantCases(Integer proImportantCases) {
        this.proImportantCases = proImportantCases;
    }

    public BigDecimal getProImportantCasesMny() {
        return proImportantCasesMny;
    }

    public void setProImportantCasesMny(BigDecimal proImportantCasesMny) {
        this.proImportantCasesMny = proImportantCasesMny;
    }

    public Integer getProThisYearAddCases() {
        return proThisYearAddCases;
    }

    public void setProThisYearAddCases(Integer proThisYearAddCases) {
        this.proThisYearAddCases = proThisYearAddCases;
    }

    public BigDecimal getProThisYearAddCasesMny() {
        return proThisYearAddCasesMny;
    }

    public void setProThisYearAddCasesMny(BigDecimal proThisYearAddCasesMny) {
        this.proThisYearAddCasesMny = proThisYearAddCasesMny;
    }

    public Integer getProThisYearEndCases() {
        return proThisYearEndCases;
    }

    public void setProThisYearEndCases(Integer proThisYearEndCases) {
        this.proThisYearEndCases = proThisYearEndCases;
    }

    public BigDecimal getProThisYearEndMny() {
        return proThisYearEndMny;
    }

    public void setProThisYearEndMny(BigDecimal proThisYearEndMny) {
        this.proThisYearEndMny = proThisYearEndMny;
    }

    public Integer getSevenDaysAddCases() {
        return sevenDaysAddCases;
    }

    public void setSevenDaysAddCases(Integer sevenDaysAddCases) {
        this.sevenDaysAddCases = sevenDaysAddCases;
    }

    public Integer getProSevenDaysAddCases() {
        return proSevenDaysAddCases;
    }

    public void setProSevenDaysAddCases(Integer proSevenDaysAddCases) {
        this.proSevenDaysAddCases = proSevenDaysAddCases;
    }
}
